summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_imp.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /kig/objects/object_imp.h
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/objects/object_imp.h')
-rw-r--r--kig/objects/object_imp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kig/objects/object_imp.h b/kig/objects/object_imp.h
index 8e12de26..eaf29328 100644
--- a/kig/objects/object_imp.h
+++ b/kig/objects/object_imp.h
@@ -268,7 +268,7 @@ public:
virtual ObjectImp* transform( const Transformation& t ) const = 0;
virtual void draw( KigPainter& p ) const = 0;
- virtual bool tqcontains( const Coordinate& p, int width,
+ virtual bool contains( const Coordinate& p, int width,
const KigWidget& si ) const = 0;
virtual bool inRect( const Rect& r, int width,
const KigWidget& si ) const = 0;
@@ -327,7 +327,7 @@ public:
virtual ObjectImp* copy() const = 0;
// s is a string with at least one escape ( "%N" where N is a
- // number ) somewhere. This function tqreplaces the first escape it
+ // number ) somewhere. This function replaces the first escape it
// sees with the "value" of this imp ( using the TQString::arg
// functions ). This is e.g. used by TextType to turn its variable
// args into strings..
@@ -341,7 +341,7 @@ public:
/**
* Returns true if this ObjectImp is equal to rhs.
* This function checks whether rhs is of the same ObjectImp type,
* and whether it tqcontains the same data as this ObjectImp.
* \internal It is used e.g. by the KigCommand stuff to see what the
* user has changed during a move..
*/
@@ -341,7 +341,7 @@ public:
* Returns true if this ObjectImp is equal to rhs.
* This function checks whether rhs is of the same ObjectImp type,
- * and whether it tqcontains the same data as this ObjectImp.
+ * and whether it contains the same data as this ObjectImp.
* \internal It is used e.g. by the KigCommand stuff to see what the
* user has changed during a move..